@@ -8,6 +8,7 @@ import json
 import time
 import socket
 import subprocess
+import signal
 from tabulate import tabulate
 from pathlib import Path
 from subprocess import Popen, PIPE
@@ -172,7 +173,8 @@ class CAM(object):
                             taskinfo = taskinfo if tf is None else json.dumps(tf) 
                             self._set_by_tid("running", self.running_job_id, taskinfo)
                             if self._get_by_tid("running", self.running_job_id)[-1] == "KILLED":
-                                self.p.kill()
+                                os.killpg(os.getpgid(self.p.pid), signal.SIGINT)
+                                #self.p.kill()
                                 log_warn("Task ", str(self.running_job_id), " has been killed.")
                                 break
                         except:
